@@ -506,160 +506,6 @@ def decode_quotes(value:str)->str:
     return value
 
 
-# def strip_excessive_spaces(value:str)->str:
-#     '''
-#         Removes excessive (2 or more consecutive) spaces from the string.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `value` {str}
-#             The string to format.
-
-#         Return {str}
-#         ----------------------
-#         The formatted string
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 12-09-2021 08:19:28
-#         `memberOf`: string_format
-#         `version`: 1.0
-#         `method_name`: strip_excessive_spaces
-#     '''
-#     return _re.sub(r'[\s\s]{2,}', ' ', value)
-
-
-# def strip_excessive_chars(value:str,chars:_Union[str,list])->str:
-#     '''
-#         Removes excessive (2 or more consecutive) chars from the string.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `value` {str}
-#             The string to format.
-#         `chars` {str|list}
-#             The chars to remove if they occur excessively.
-
-#         Return {str}
-#         ----------------------
-#         The formatted string
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 06-03-2022 11:47:37
-#         `memberOf`: string_format
-#         `version`: 1.0
-#         `method_name`: strip_excessive_chars
-#     '''
-#     if isinstance(chars,(str)):
-#         chars = [chars]
-#     for c in chars:
-#         if c == " ":
-#             c = "\\s"
-#         reg_c = escape_regex(c)
-#         exp = rf"[{reg_c}]{{2,}}"
-#         # print(exp)
-#         reg = _re.compile(exp)
-#         value = _re.sub(reg, c, value)
-#     return value
-
-
-# def escape_regex(value:str)->str:
-#     '''
-#         Escapes regex special characters.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `value` {str}
-#             The string to escape.
-
-#         Return {str}
-#         ----------------------
-#         The formatted string.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 12-09-2021 08:46:32
-#         `memberOf`: string_format
-#         `version`: 1.0
-#         `method_name`: escape_regex
-#     '''
-#     regex_chars = ["\\", "^", "$", "{", "}", "[", "]", "(", ")", ".", "*", "+", "?", "<", ">", "-", "&"]
-#     for char in regex_chars:
-#         value = value.replace(char, f"\\{char}")
-#     return value
-
-# def strip_any(value,chars,side='both'):
-#     '''
-#         Strips characters/strings from the beginning,end or both sides of a string.
-
-#         ----------
-
-#         Arguments
-#         -------------------------
-#         `value` {str}
-#             The value to be formatted
-#         `chars` {list}
-#             A list of strings to be stripped from the value
-#         [`side`='both'] {str}
-#             Can be "left", "right", "both"
-
-#         Return {str}
-#         ----------------------
-#         The formatted value.
-
-#         Meta
-#         ----------
-#         `author`: Colemen Atwood
-#         `created`: 02-04-2022 10:25:04
-#         `memberOf`: string_format
-#         `version`: 1.0
-#         `method_name`: strip_any
-#     '''
-#     new_value = value
-#     cycle = True
-#     if side in ["both","left"]:
-#         cycle = True
-#         while cycle is True:
-#             matchFound = False
-#             for char in chars:
-#                 if new_value.startswith(char):
-#                     new_value = new_value[len(char):]
-#                     matchFound = True
-#                 else:
-#                     continue
-#             if matchFound is False:
-#                 cycle = False
-#     if side in ["both","right"]:
-#         cycle = True
-#         while cycle is True:
-#             matchFound = False
-#             for char in chars:
-#                 if new_value.endswith(char):
-#                     new_value = new_value[:-len(char)]
-#                     matchFound = True
-#                 else:
-#                     continue
-#             if matchFound is False:
-#                 cycle = False
-#     return new_value
-
-
-
-# def strip_end(text, suffix):
-#     if suffix and text.endswith(suffix):
-#         return text[:-len(suffix)]
-#     return text
-
 
 def windows_file_name(file_name:str)->str:
     '''
@@ -907,47 +753,6 @@ def strip_empty_lines(value:str)->str:
 
 
 
-# def reverse_sanitize_quotes(string):
-#     orig_list = False
-#     if isinstance(string, (list)):
-#         orig_list = True
-#     if isinstance(string, (str)):
-#         string = [string]
-
-#     new_list = []
-#     for item in string:
-#         item = item.replace("&apos_", "'")
-#         item = item.replace("&quot_", '"')
-#         new_list.append(item)
-
-#     if len(new_list) == 1 and orig_list is False:
-#         return new_list[0]
-
-#     return new_list
-
-# def sanitize_quotes(string):
-#     orig_list = False
-#     if isinstance(string, (list)):
-#         orig_list = True
-#     if isinstance(string, (str)):
-#         string = [string]
-
-#     new_list = []
-#     for item in string:
-#         if isinstance(item, (str)):
-#             item = item.replace("'", "&apos_")
-#             item = item.replace('"', "&quot_")
-#         new_list.append(item)
-
-#     if len(new_list) == 1 and orig_list is False:
-#         return new_list[0]
-
-#     return new_list
-
-
-
-
-
 def array_in_string(array, value, default=False):
     '''
         iterates the array provided checking if any element exists in the value.
@@ -1042,6 +847,50 @@ def array_replace_string(value,needles, new_string="", **kwargs):
 
     return result_string
 
+def dict_replace_string(value:str,replace:dict):
+    '''
+        Replace all keys with their values in the value string.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `value` {string}
+            The string to replace values in.
+            
+        `replace` {dict}
+            The dictionary to use for replacements.
+            
+            "find":"replace"
+
+
+        Return {string|None}
+        ----------------------
+        The formatted value if successful, None otherwise.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-29-2022 05:15:10
+        `memberOf`: string_format
+        `version`: 1.0
+        `method_name`: dict_replace_string
+        * @xxx [06-29-2022 05:17:05]: documentation for dict_replace_string
+    '''
+
+
+    if isinstance(replace,(dict)) is False:
+        print(f"The replace argument must be a dictionary")
+        return None
+    
+    for k,v in replace:
+        if v is not None:
+            value = value.replace(k,v)
+    return value
+
+
+
+
 # def _get_numeric_charcode(char):
 #     for _,v in _numeric_char_codes.items():
 #         for c,code in v.items():
